Milter replacing RCTP TO addresses with configured ones

Intended to muzzle a mail-sending application while only touching its mail
relay.

"munnel" is a portmanteau, like milter: milter is a Mail fILTER, munnel is a
Mail fUNNEL. And it is a funnel, because wherever the mail tries to fall, it
will slide where configurations tells it to.
